#ifndef CREDINJECT_H
#define CREDINJECT_H

#ifdef __cplusplus
namespace CitrixSSOnSDK
{
extern "C"
{
#endif

enum LOGONSSOUSER_ERROR_CODE
{
    LOGONSSOUSER_OK = 0,
    LOGONSSOUSER_INVALID_REQUEST_TYPE = -1,
    LOGONSSOUSER_INVALID_PARAMETER = -2,
    LOGONSSOUSER_INITIALIZATION_FAILED = -3,
    LOGONSSOUSER_UNABLE_TO_CONNECT_TO_SSO = -4,
    LOGONSSOUSER_UNABLE_TO_SEND_REQUEST = -5,
    LOGONSSOUSER_UNABLE_TO_RECEIVE_RESPONSE = -6,
    LOGONSSOUSER_SERVER_INTERNAL_ERROR = -7,
    LOGONSSOUSER_CONTAINER_FULL = -8,
    LOGONSSOUSER_UNAUTHORIZED = -9,
    LOGONSSOUSER_SERVER_IPC_ERROR = -10
};

/**
 * @brief Logs on a new user using the specified credentials (username, domain, password).
 *
 * @param username The username to use for the logon.
 * @param domain The domain to use for the logon.
 * @param password The password to use for the logon.
 *
 * @return 0 if successful, otherwise an error code.
 */
LOGONSSOUSER_ERROR_CODE LogonSsoUser(const wchar_t *username, const wchar_t *domain, const wchar_t *password);

/**
 * @brief Logs on a new user using the specified credentials (PIN).
 *
 * @param pin A smartcard PIN to be stored.
 *
 * @return 0 if successful, otherwise an error code.
 */
LOGONSSOUSER_ERROR_CODE LogonSsoUserWithPin(const wchar_t *pin);

/**
 * @brief Removes the credentials currently stored at the top of the SSO container stack.
 *
 * @return 0 if successful, otherwise an error code.
 */
int LogoffSsoUser();

/**
 * @brief Returns the description of the given error code.
 *
 * @param errorCode The error code for which to get the description.
 *
 * @return The description of the given error code.
 */
const wchar_t *ErrorDescription(LOGONSSOUSER_ERROR_CODE errorCode);

#ifdef __cplusplus
} // extern "C"
} // namespace CitrixSSOnSDK
#endif

#endif // CREDINJECT_H
